@@ -313,3 +313,22 @@ def test_change_existing_styles(datadir):
     assert ws['A26'].alignment == Alignment(shrink_to_fit=False)
 
     assert ws.column_dimensions['A'].width == 20.0
+
+
+def test_none_values(datadir, StyleReader):
+    datadir.chdir()
+    with open("none_value_styles.xml") as src:
+        reader = StyleReader(src.read())
+    fonts = tuple(reader.parse_fonts())
+    assert fonts[0].scheme is None
+    assert fonts[0].vertAlign is None
+    assert fonts[1].u is None
+
+
+def test_alignment(datadir, StyleReader):
+    datadir.chdir()
+    with open("alignment_styles.xml") as src:
+        reader = StyleReader(src.read())
+    reader.parse_cell_xfs()
+    st1 = reader.shared_styles[2]
+    assert st1.alignment.textRotation == 255
