@@ -9,6 +9,7 @@ from openpyxl.compat import unicode
 from openpyxl.formatting import ConditionalFormatting
 from openpyxl.formatting.rules import FormulaRule
 
+from openpyxl.xml.functions import SubElement
 from openpyxl.styles import (
     Alignment,
     numbers,
@@ -183,6 +184,36 @@ class TestStyleWriter(object):
         assert diff is None, diff
 
 
+    def test_xfs_number_format(self):
+        for o in range(1, 4):
+            for i in range(1, 4):
+                # Two of these are custom, 0.0% and 0.000%. 0.00% is a built in format ID
+                self.worksheet.cell(row=o, column=i).number_format = '0.' + '0' * i + '%'
+        w = StyleWriter(self.workbook)
+        fonts = borders = fills = DummyElement()
+        nft = SubElement(w._root, 'numFmts')
+        w._write_cell_xfs(nft, fonts, fills, borders)
+
+        expected = """
+        <styleSheet xmlns="http://schemas.openxmlformats.org/spreadsheetml/2006/main">
+            <numFmts count="2">
+                <numFmt formatCode="0.0%" numFmtId="165"/>
+                <numFmt formatCode="0.000%" numFmtId="166"/>
+            </numFmts>
+            <cellXfs count="4">
+                <xf borderId="0" fillId="0" fontId="0" numFmtId="0" xfId="0"/>
+                <xf applyNumberFormat="1" borderId="0" fillId="0" fontId="0" numFmtId="165" xfId="0"/>
+                <xf applyNumberFormat="1" borderId="0" fillId="0" fontId="0" numFmtId="10" xfId="0"/>
+                <xf applyNumberFormat="1" borderId="0" fillId="0" fontId="0" numFmtId="166" xfId="0"/>
+            </cellXfs>
+        </styleSheet>
+        """
+
+        xml = tostring(w._root)
+        diff = compare_xml(xml, expected)
+        assert diff is None, diff
+
+
     def test_xfs_fonts(self):
         st = Style(font=Font(size=12, bold=True))
         self.worksheet.cell('A1').style = st
