@@ -627,7 +627,7 @@ def test_formula_rule(worksheet_with_cf, write_conditional_formatting):
                              (True, """<c t="b" r="A1"><v>1</v></c>"""),
                              ("Hello", """<c t="s" r="A1"><v>0</v></c>"""),
                              ("", """<c r="A1" t="s"></c>"""),
-                             (None, """<c r="A1" t="s"></c>"""),
+                             (None, """<c r="A1" t="n"></c>"""),
                              (datetime.date(2011, 12, 25), """<c r="A1" t="n" s="1"><v>40902</v></c>"""),
                          ])
 def test_write_cell(out, doc, worksheet, value, expected):
